# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['majel',
 'majel.actions',
 'majel.actions.browser',
 'majel.actions.browser.handlers']

package_data = \
{'': ['*']}

install_requires = \
['kodi-json>=1.0.0,<2.0.0',
 'python-mpv>=0.4.6,<0.5.0',
 'pyyaml>=5.3.1,<6.0.0',
 'requests>=2.23.0,<3.0.0',
 'selenium>=3.141.0,<4.0.0',
 'websockets>=8.1,<9.0']

entry_points = \
{'console_scripts': ['majel = majel.command:Majel.run']}

setup_kwargs = {
    'name': 'majel',
    'version': '0.4.0',
    'description': 'A front-end for Mycroft that allows you to do cool things like stream video or surf the web.',
    'long_description': '# Majel\n\n[![GitLab](https://img.shields.io/badge/GitLab-Majel-%23FCA121?logo=gitlab&url=https://gitlab.com/danielquinn/majel)](https://gitlab.com/danielquinn/majel)\n[![License](https://img.shields.io/pypi/l/majel)](https://gitlab.com/danielquinn/majel/blob/master/LICENSE)\n[![PyPI](https://img.shields.io/pypi/pyversions/majel)](https://pypi.org/project/majel/)\n[![Flake8](https://img.shields.io/badge/linter-flake8-informational.svg)](https://flake8.pycqa.org/en/latest/)\n[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n[![Downloads](https://img.shields.io/pypi/dm/majel)](https://pypi.org/project/majel/)\n\nA visual front-end for [Mycroft](https://mycroft.ai/).\n\n![Architecture](https://gitlab.com/danielquinn/majel/-/raw/master/architecture.png)\n\n\n## What can it do?\n\n[![A demo of Majel](https://gitlab.com/danielquinn/majel/-/raw/master/demo-thumbnail.png)](https://danielquinn.org/static/project/majel-demo.webm)\n\n\nMajel listens to the [Mycroft message bus framework](https://mycroft-ai.gitbook.io/docs/mycroft-technologies/mycroft-core/message-bus)\nand performs various desktop jobs based on what it comes down that pipe.  The\nresult is that you get Mycroft\'s standard skills along with:\n\n\n### Youtube player\n\nSay `Hey Mycroft, youtube <query>` and it\'ll search Youtube for your `query`,\npick the first hit, and play it full screen in a loop.\n\n\n### Kodi\n\nIf you\'ve got a local Kodi installation *and* the video files you\'ve got in\nthere are also mounted locally, you can say `Hey Mycroft, play <query>` and\nit\'ll look for `query` in your Kodi library.  If it finds it, it\'ll play it\nwith `mpv` locally.  It\'s also smart enough to know which episodes you\'ve seen,\nso if you say `Hey Mycroft play Star Trek Deep Space Nine` and you\'ve already\nseen all of season 4, it\'ll start with s05e01.  It\'ll also pick up right where\nyou left off in that episode.\n\n\n### Netflix & Amazon Prime\n\nThe `play` keyword will also fall back to Netflix or Amazon Prime if you don\'t\nhave Kodi installed, or simply don\'t have the video you were asking for.  In\nthis case, it\'ll hit up the [Utelly API](https://rapidapi.com/utelly/api/utelly)\nto see which streaming service has the movie/show you asked for, and then point\nyour browser to that show and play the next episode.\n\nNote that this functionality requires two things: a Utelly API key (it\'s free\nfor limited use, and we\'ve got built-in caching so you\'ll never break the\n1000/mo limit) and a subscription to Netflix and/or Amazon Prime.\n\n\n### Browser Bookmarks\n\nIf you store your bookmarks in Firefox, you can say\n`Hey Mycroft, search my bookmarks for <query>`.  This will rank your bookmarks\nby relevance to your query and display a list of everything it found within a\nthreshold.  The list appears as a touchscreen-friendly UI so you can say *"Hey\nMycroft, search my bookmarks for chicken"* and select from your 12 favourite\nchicken recipes.\n\n\n## Configuration\n\nConfiguration of the skills is done separately for each skill via Mycroft\'s\nstandard settings UI at [home.mycroft.ai](https://home.mycroft.ai/).  That\'s\nwhere, for example, you input your YouTube API key and Utelly API key.\n\nMajel is configured by way of a single config file you place in\n`/etc/majel.yml`.  Simply copy the [example file](https://gitlab.com/danielquinn/majel/-/raw/master/majel.yml.example)\nfrom the root of this project as a starting point and edit the values in there\nto fit your preference.  Full details on what values do what are in the example\nfile.\n\n\n## This is Complicated, I Need Help\n\nGetting Mycroft up and running locally can be difficult, and setting it up in\nconcert with Majel is even more fiddly.  To make things easier, there\'s a handy\n[scaffolding app](https://gitlab.com/danielquinn/majel-scaffolding) that\ncombines Docker+Mycroft with Majel to make things a little easier.  If you want\nto try this out, that\'s probably your best first step.\n\n\n## What\'s Next?\n\nIt\'d be nice to have support for doing video calls: `Hey Mycroft, call my\nparents`, but that may not be easy to do since most video calling platforms\nseem to either be centred around scheduled group chat (Jitsi/Zoom), or just\nplain Linux/browser hostile (Skype).  Perhaps combining Pygui with Signal could\ndo the job though...\n\n\n## Colophon\n\nFor [Majel Barrett-Roddenberry](https://en.wikipedia.org/wiki/Majel_Barrett),\nwho was amazing.\n\n\n## Change Log\n\n### 0.4.0 (Denobulan)\n\n* Modified the default page to communicate directly with Mycroft.  You can now\n  tap the Majel logo to get Mycroft to listen (instead of having to say\n  *"Hey Mycroft"*).  It will now also tell you when it\'s listening and write\n  out what it\'s saying.\n* Added support for authentication against the Kodi API.\n* If started when Mycroft is unavailable (typical if you\'re starting both\n  Mycroft and Majel at the same time), Majel will now politely wait for Mycroft\n  to come online rather than exploding with a traceback.\n* Added some tests and polished the CI to support Python 3.8 and 3.9.\n\n\n### 0.3.1 (Cardassian)\n\n* Added `websockets` and `flake8` to the list of dependencies.\n\n\n### 0.3.0 (Cardassian)\n\n* **Breaking change**: The endpoint for Mycroft\'s websocket is now\n  configurable.  Note that this requires a change to `/etc/majel.yml`.  See the\n  `majel.yml.example` file for more information.\n* Refactored the `Command` class to drop Mycroft\'s `MessageClient` in favour of\n  a [websockets](https://pypi.org/project/websockets/) -based, async-friendly\n  loop.\n* Dropped Mycroft\'s `Message` class in favour of a simpler dataclass.\n* As a perk of the above changes, the dropping of `mycroft-message-bus` as a\n  dependency should placate the grumpy folks unhappy with Majel\'s AGPL license.\n* Added the beginnings of a CI run.  At this stage, it\'s just enough to check\n  that the code conforms to style rules.\n* Fixed how we handle "noisy" actions.  Previously it was possible to start a\n  Youtube video and then start a Kodi stream and have the two media sources\n  play concurrently.\n\n\n### 0.2.4 (Bajoran)\n\n* Fixed a logo rendering problem on the home page.\n\n\n### 0.2.3 (Bajoran)\n\n* Added a proper logo.\n* Removed the rotating wallpaper from the home page.\n\n\n### 0.2.2 (Bajoran)\n\n* Tweaked the Amazon handler to widen the range of URLs it\'ll claim.\n* Fixed the click event on the Amazon handler so now it actually plays the\n  video when you get to the page.\n* Refactored the way we detect whether a browser action is "noisy".  The\n  functionality hasn\'t changed, but now there\'s a nice way to override how that\n  detection works should someone want to.\n* Added more logging to make it easier to understand what\'s going on.\n* Added a demo video to the `README`.\n\n\n### 0.2.1 (Bajoran)\n\n* Added this file!\n* Fixed the handling of a race condition when Mycroft sends a `stop` signal\n  over the message bus for one service and a `play` signal for another one.\n* Added a click event to auto-play Netflix streams.\n* Added some more debugging information\n\n\n### 0.2.0 (Bajoran)\n\n* Switch to Firefox for the browser actions.  I was never happy depending on\n  Google tech for a Free software project, and since we\'re using Firefox\'s\n  bookmarks anyway, this only made sense.\n* Drop the use of environment variables in favour of `/etc/mycroft.yml`.\n* Update dependencies.\n\n\n### 0.1.1 (Andorian)\n\n* Cosmetic updates for PyPI\n\n\n### 0.1.0 (Andorian)\n\n* Initial release\n',
    'author': 'Daniel Quinn',
    'author_email': 'code@danielquinn.org',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://gitlab.com/danielquinn/majel',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
